@@ -4,14 +4,14 @@ from typing import Any, Callable
 import httpx
 from fastapi import FastAPI
 
-from j3.core import AbstractFastMSA
+from j3.core import AbstractJ3
 
 # globals
 app: FastAPI = FastAPI(title=__name__)  # pylint:
 
 
 def init_app(
-    msa: AbstractFastMSA, init_hook: Callable[[AbstractFastMSA, FastAPI], Any] = None
+    msa: AbstractJ3, init_hook: Callable[[AbstractJ3, FastAPI], Any] = None
 ) -> FastAPI:
     """FastAPI 앱을 초기화 합니다.
 
