@@ -1,9 +1,9 @@
 import asyncio
 
 from j3.api import app  # noqa
-from j3.command import FastMSACommand
+from j3.command import J3Command
 
-cmd = FastMSACommand()
+cmd = J3Command()
 msa = cmd.init_app()
 
 
